/*
 * Copyright (C) 2025 Piotr Caban
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#if 0
#pragma makedep install
#endif

[
    object,
    uuid(0c733a9b-2a1c-11ce-ade5-00aa0044773d),
    pointer_default(unique)
]
interface IViewFilter : IUnknown
{
    [local]
    HRESULT GetFilter([in] HACCESSOR haccessor,
                      [out] DBCOUNTITEM *rows,
                      [out] DBCOMPAREOP *compare[],
                      [out] void *criteria);

    [local]
    HRESULT GetFilterBindings([out] DBCOUNTITEM *bindings_count,
                              [out] DBBINDING **bindings);

    [call_as(GetFilterBindings)]
    HRESULT RemoteGetFilterBindings([in, out] DBCOUNTITEM *bindings_count,
                                    [out, size_is(, (ULONG)*bindings_count)] DBBINDING **bindings,
                                    [out] IErrorInfo **err_info);

    [local]
    HRESULT SetFilter([in] HACCESSOR haccessor,
                      [in] DBCOUNTITEM rows,
                      [in] DBCOMPAREOP compare[],
                      [in] void *criteria);
}
