/*** Autogenerated by WIDL 11.0 from ../wine-11.0/include/dragdropinterop.idl - Do not edit ***/

#ifdef _WIN32
#ifndef __REQUIRED_RPCNDR_H_VERSION__
#define __REQUIRED_RPCNDR_H_VERSION__ 475
#endif
#include <rpc.h>
#include <rpcndr.h>
#endif

#ifndef COM_NO_WINDOWS_H
#include <windows.h>
#include <ole2.h>
#endif

#ifndef __dragdropinterop_h__
#define __dragdropinterop_h__

/* Forward declarations */

#ifndef __IDragDropManagerInterop_FWD_DEFINED__
#define __IDragDropManagerInterop_FWD_DEFINED__
typedef interface IDragDropManagerInterop IDragDropManagerInterop;
#ifdef __cplusplus
interface IDragDropManagerInterop;
#endif /* __cplusplus */
#endif

/* Headers for imported files */

#include <inspectable.h>

#ifdef __cplusplus
extern "C" {
#endif

/*****************************************************************************
 * IDragDropManagerInterop interface
 */
#ifndef __IDragDropManagerInterop_INTERFACE_DEFINED__
#define __IDragDropManagerInterop_INTERFACE_DEFINED__

DEFINE_GUID(IID_IDragDropManagerInterop, 0x5ad8cba7, 0x4c01, 0x4dac, 0x90,0x74, 0x82,0x78,0x94,0x29,0x2d,0x63);
#if defined(__cplusplus) && !defined(CINTERFACE)
MIDL_INTERFACE("5ad8cba7-4c01-4dac-9074-827894292d63")
IDragDropManagerInterop : public IInspectable
{
    virtual HRESULT STDMETHODCALLTYPE GetForWindow(
        HWND hwnd,
        REFIID riid,
        void **ppv) = 0;

};
#ifdef __CRT_UUID_DECL
__CRT_UUID_DECL(IDragDropManagerInterop, 0x5ad8cba7, 0x4c01, 0x4dac, 0x90,0x74, 0x82,0x78,0x94,0x29,0x2d,0x63)
#endif
#else
typedef struct IDragDropManagerInteropVtbl {
    BEGIN_INTERFACE

    /*** IUnknown methods ***/
    HRESULT (STDMETHODCALLTYPE *QueryInterface)(
        IDragDropManagerInterop *This,
        REFIID riid,
        void **ppvObject);

    ULONG (STDMETHODCALLTYPE *AddRef)(
        IDragDropManagerInterop *This);

    ULONG (STDMETHODCALLTYPE *Release)(
        IDragDropManagerInterop *This);

    /*** IInspectable methods ***/
    HRESULT (STDMETHODCALLTYPE *GetIids)(
        IDragDropManagerInterop *This,
        ULONG *iidCount,
        IID **iids);

    HRESULT (STDMETHODCALLTYPE *GetRuntimeClassName)(
        IDragDropManagerInterop *This,
        HSTRING *className);

    HRESULT (STDMETHODCALLTYPE *GetTrustLevel)(
        IDragDropManagerInterop *This,
        TrustLevel *trustLevel);

    /*** IDragDropManagerInterop methods ***/
    HRESULT (STDMETHODCALLTYPE *GetForWindow)(
        IDragDropManagerInterop *This,
        HWND hwnd,
        REFIID riid,
        void **ppv);

    END_INTERFACE
} IDragDropManagerInteropVtbl;

interface IDragDropManagerInterop {
    CONST_VTBL IDragDropManagerInteropVtbl* lpVtbl;
};

#ifdef COBJMACROS
#ifndef WIDL_C_INLINE_WRAPPERS
/*** IUnknown methods ***/
#define IDragDropManagerInterop_QueryInterface(This,riid,ppvObject) (This)->lpVtbl->QueryInterface(This,riid,ppvObject)
#define IDragDropManagerInterop_AddRef(This) (This)->lpVtbl->AddRef(This)
#define IDragDropManagerInterop_Release(This) (This)->lpVtbl->Release(This)
/*** IInspectable methods ***/
#define IDragDropManagerInterop_GetIids(This,iidCount,iids) (This)->lpVtbl->GetIids(This,iidCount,iids)
#define IDragDropManagerInterop_GetRuntimeClassName(This,className) (This)->lpVtbl->GetRuntimeClassName(This,className)
#define IDragDropManagerInterop_GetTrustLevel(This,trustLevel) (This)->lpVtbl->GetTrustLevel(This,trustLevel)
/*** IDragDropManagerInterop methods ***/
#define IDragDropManagerInterop_GetForWindow(This,hwnd,riid,ppv) (This)->lpVtbl->GetForWindow(This,hwnd,riid,ppv)
#else
/*** IUnknown methods ***/
static inline HRESULT IDragDropManagerInterop_QueryInterface(IDragDropManagerInterop* This,REFIID riid,void **ppvObject) {
    return This->lpVtbl->QueryInterface(This,riid,ppvObject);
}
static inline ULONG IDragDropManagerInterop_AddRef(IDragDropManagerInterop* This) {
    return This->lpVtbl->AddRef(This);
}
static inline ULONG IDragDropManagerInterop_Release(IDragDropManagerInterop* This) {
    return This->lpVtbl->Release(This);
}
/*** IInspectable methods ***/
static inline HRESULT IDragDropManagerInterop_GetIids(IDragDropManagerInterop* This,ULONG *iidCount,IID **iids) {
    return This->lpVtbl->GetIids(This,iidCount,iids);
}
static inline HRESULT IDragDropManagerInterop_GetRuntimeClassName(IDragDropManagerInterop* This,HSTRING *className) {
    return This->lpVtbl->GetRuntimeClassName(This,className);
}
static inline HRESULT IDragDropManagerInterop_GetTrustLevel(IDragDropManagerInterop* This,TrustLevel *trustLevel) {
    return This->lpVtbl->GetTrustLevel(This,trustLevel);
}
/*** IDragDropManagerInterop methods ***/
static inline HRESULT IDragDropManagerInterop_GetForWindow(IDragDropManagerInterop* This,HWND hwnd,REFIID riid,void **ppv) {
    return This->lpVtbl->GetForWindow(This,hwnd,riid,ppv);
}
#endif
#endif

#endif


#endif  /* __IDragDropManagerInterop_INTERFACE_DEFINED__ */

/* Begin additional prototypes for all interfaces */


/* End additional prototypes */

#ifdef __cplusplus
}
#endif

#endif /* __dragdropinterop_h__ */
