/*
 * Copyright (C) 2013 Alistair Leslie-Hughes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

#if 0
#pragma makedep install
#endif

[
    object,
    uuid(0c733a1e-2a1c-11ce-ade5-00aa0044773d),
    pointer_default(unique)
]
interface ISourcesRowset : IUnknown
{
    typedef DWORD DBSOURCETYPE;

    enum DBSOURCETYPEENUM
    {
        DBSOURCETYPE_DATASOURCE     = 1,
        DBSOURCETYPE_ENUMERATOR     = 2,
    };

    enum DBSOURCETYPEENUM20
    {
        DBSOURCETYPE_DATASOURCE_TDP = 1,
        DBSOURCETYPE_DATASOURCE_MDP = 3,
    };

    enum DBSOURCETYPEENUM25
    {
        DBSOURCETYPE_BINDER         = 4,
    };

    [local]
    HRESULT GetSourcesRowset([in] IUnknown * pUnkOuter, [in] REFIID riid, [in] ULONG cPropertySets,
        [in, out] DBPROPSET rgProperties[], [out] IUnknown **ppSourcesRowset);

    [call_as(GetSourcesRowset)]
    HRESULT RemoteGetSourcesRowset([in] IUnknown * pUnkOuter, [in] REFIID riid, [in] ULONG cPropertySets,
        [in] DBPROPSET * rgProperties, [out] IUnknown **ppSourcesRowset, [in] ULONG cTotalProps,
        [out] DBPROPSTATUS *rgPropStatus, [out] IErrorInfo **ppErrorInfoRem);
}
