/*
 * Copyright 2021 Nikolay Sivov for CodeWeavers
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

import "xpsobjectmodel.idl";

typedef [v1_enum] enum
{
    XPS_DOCUMENT_TYPE_UNSPECIFIED = 1,
    XPS_DOCUMENT_TYPE_XPS,
    XPS_DOCUMENT_TYPE_OPENXPS
} XPS_DOCUMENT_TYPE;

[
    object,
    local,
    pointer_default(ref),
    uuid(3b0b6d38-53ad-41da-b212-d37637a6714e),
]
interface IXpsDocumentPackageTarget : IUnknown
{
    HRESULT GetXpsOMPackageWriter(
        [in] IOpcPartUri *documentpart,
        [in] IOpcPartUri *controlpart,
        [out, retval] IXpsOMPackageWriter **writer
    );

    HRESULT GetXpsOMFactory(
        [out, retval] IXpsOMObjectFactory **factory
    );

    HRESULT GetXpsType(
        [out, retval] XPS_DOCUMENT_TYPE *document_type
    );
}
