/*
 * Copyright 2017 Owen Rudge for CodeWeavers
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

import "oaidl.idl";
import "ocidl.idl";
import "wsdxmldom.h";

interface IWSDXMLContext;

[
uuid(75d8f3ee-3e5a-43b4-a15a-bcf6887460c0),
object,
local,
restricted,
pointer_default(unique)
]
interface IWSDXMLContext : IUnknown
{
    HRESULT AddNamespace([in] LPCWSTR pszUri, [in] LPCWSTR pszSuggestedPrefix, [out] WSDXML_NAMESPACE** ppNamespace);

    HRESULT AddNameToNamespace([in] LPCWSTR pszUri, [in] LPCWSTR pszName, [out] WSDXML_NAME** ppName);

    HRESULT SetNamespaces([in, size_is(wNamespacesCount)] const PCWSDXML_NAMESPACE* pNamespaces, [in] WORD wNamespacesCount, [in] BYTE bLayerNumber);

    HRESULT SetTypes([in, size_is(dwTypesCount)] const PCWSDXML_TYPE* pTypes, [in] DWORD dwTypesCount, [in] BYTE bLayerNumber);
}

cpp_quote("HRESULT WINAPI WSDXMLCreateContext(IWSDXMLContext **ppContext);")
