/*
 * structured query condition
 *
 * Copyright 2009 Maarten Lankhorst
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 *
 */


import "oaidl.idl";
import "ocidl.idl";
import "objidl.idl";
import "propidl.idl";

typedef [v1_enum] enum tagCONDITION_TYPE
{
    CT_AND_CONDITION,
    CT_OR_CONDITION,
    CT_NOT_CONDITION,
    CT_LEAF_CONDITION
} CONDITION_TYPE;

typedef [v1_enum] enum tagCONDITION_OPERATION
{
    COP_IMPLICIT,
    COP_EQUAL,
    COP_NOTEQUAL,
    COP_LESSTHAN,
    COP_GREATERTHAN,
    COP_LESSTHANOREQUAL,
    COP_GREATERTHANOREQUAL,
    COP_VALUE_STARTSWITH,
    COP_VALUE_ENDSWITH,
    COP_VALUE_CONTAINS,
    COP_VALUE_NOTCONTAINS,
    COP_DOSWILDCARDS,
    COP_WORD_EQUAL,
    COP_WORD_STARTSWITH,
    COP_APPLICATION_SPECIFIC
} CONDITION_OPERATION;
