/*
 * Copyright (C) 2014 Alexandre Julliard
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

OUR_GUID_ENTRY(AM_INTERFACESETID_Standard,                  0x1a8766a0, 0x62ce, 0x11cf, 0xa5, 0xd6, 0x28, 0xdb, 0x04, 0xc1, 0x00, 0x00)
OUR_GUID_ENTRY(AM_KSCATEGORY_AUDIO,                         0x6994ad04, 0x93ef, 0x11d0, 0xa3, 0xcc, 0x00, 0xa0, 0xc9, 0x22, 0x31, 0x96)
OUR_GUID_ENTRY(AM_KSCATEGORY_CAPTURE,                       0x65e8773d, 0x8f56, 0x11d0, 0xa3, 0xb9, 0x00, 0xa0, 0xc9, 0x22, 0x31, 0x96)
OUR_GUID_ENTRY(AM_KSCATEGORY_CROSSBAR,                      0xa799a801, 0xa46d, 0x11d0, 0xa1, 0x8c, 0x00, 0xa0, 0x24, 0x01, 0xdc, 0xd4)
OUR_GUID_ENTRY(AM_KSCATEGORY_DATACOMPRESSOR,                0x1e84c900, 0x7e70, 0x11d0, 0xa5, 0xd6, 0x28, 0xdb, 0x04, 0xc1, 0x00, 0x00)
OUR_GUID_ENTRY(AM_KSCATEGORY_RENDER,                        0x65e8773e, 0x8f56, 0x11d0, 0xa3, 0xb9, 0x00, 0xa0, 0xc9, 0x22, 0x31, 0x96)
OUR_GUID_ENTRY(AM_KSCATEGORY_SPLITTER,                      0x0a4252a0, 0x7e70, 0x11d0, 0xa5, 0xd6, 0x28, 0xdb, 0x04, 0xc1, 0x00, 0x00)
OUR_GUID_ENTRY(AM_KSCATEGORY_TVAUDIO,                       0xa799a802, 0xa46d, 0x11d0, 0xa1, 0x8c, 0x00, 0xa0, 0x24, 0x01, 0xdc, 0xd4)
OUR_GUID_ENTRY(AM_KSCATEGORY_TVTUNER,                       0xa799a800, 0xa46d, 0x11d0, 0xa1, 0x8c, 0x00, 0xa0, 0x24, 0x01, 0xdc, 0xd4)
OUR_GUID_ENTRY(AM_KSCATEGORY_VBICODEC,                      0x07dad660, 0x22f1, 0x11d1, 0xa9, 0xf4, 0x00, 0xc0, 0x4f, 0xbb, 0xde, 0x8f)
OUR_GUID_ENTRY(AM_KSCATEGORY_VBICODEC_MI,                   0x9c24a977, 0x0951, 0x451a, 0x80, 0x06, 0x0e, 0x49, 0xbd, 0x28, 0xcd, 0x5f)
OUR_GUID_ENTRY(AM_KSCATEGORY_VIDEO,                         0x6994ad05, 0x93ef, 0x11d0, 0xa3, 0xcc, 0x00, 0xa0, 0xc9, 0x22, 0x31, 0x96)
OUR_GUID_ENTRY(AM_KSPROPSETID_AC3,                          0xbfabe720, 0x6e1f, 0x11d0, 0xbc, 0xf2, 0x44, 0x45, 0x53, 0x54, 0x00, 0x00)
OUR_GUID_ENTRY(AM_KSPROPSETID_CopyProt,                     0x0e8a0a40, 0x6aef, 0x11d0, 0x9e, 0xd0, 0x00, 0xa0, 0x24, 0xca, 0x19, 0xb3)
OUR_GUID_ENTRY(AM_KSPROPSETID_DVD_RateChange,               0x3577eb09, 0x9582, 0x477f, 0xb2, 0x9c, 0xb0, 0xc4, 0x52, 0xa4, 0xff, 0x9a)
OUR_GUID_ENTRY(AM_KSPROPSETID_DvdKaraoke,                   0xae4720ae, 0xaa71, 0x42d8, 0xb8, 0x2a, 0xff, 0xfd, 0xf5, 0x8b, 0x76, 0xfd)
OUR_GUID_ENTRY(AM_KSPROPSETID_DvdSubPic,                    0xac390460, 0x43af, 0x11d0, 0xbd, 0x6a, 0x00, 0x35, 0x05, 0xc1, 0x03, 0xa9)
OUR_GUID_ENTRY(AM_KSPROPSETID_FrameStep,                    0xc830acbd, 0xab07, 0x492f, 0x88, 0x52, 0x45, 0xb6, 0x98, 0x7c, 0x29, 0x79)
OUR_GUID_ENTRY(AM_KSPROPSETID_MPEG4_MediaType_Attributes,   0xff6c4bfa, 0x07a9, 0x4c7b, 0xa2, 0x37, 0x67, 0x2f, 0x9d, 0x68, 0x06, 0x5f)
OUR_GUID_ENTRY(AM_KSPROPSETID_TSRateChange,                 0xa503c5c0, 0x1d1d, 0x11d1, 0xad, 0x80, 0x44, 0x45, 0x53, 0x54, 0x00, 0x00)
OUR_GUID_ENTRY(FORMAT_DVD_LPCMAudio,                        0xe06d80e6, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(FORMAT_DolbyAC3,                             0xe06d80e4, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(FORMAT_Image,                                0x692fa379, 0xd3e8, 0x4651, 0xb5, 0xb4, 0x0b, 0x94, 0xb0, 0x13, 0xee, 0xaf)
OUR_GUID_ENTRY(FORMAT_JPEGImage,                            0x692fa379, 0xd3e8, 0x4651, 0xb5, 0xb4, 0x0b, 0x94, 0xb0, 0x13, 0xee, 0xaf)
OUR_GUID_ENTRY(FORMAT_MPEG2Audio,                           0xe06d80e5, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(FORMAT_MPEG2Video,                           0xe06d80e3, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(FORMAT_MPEG2_VIDEO,                          0xe06d80e3, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(FORMAT_UVCH264Video,                         0x2017be05, 0x6629, 0x4248, 0xaa, 0xed, 0x7e, 0x1a, 0x47, 0xbc, 0x9b, 0x9c)
OUR_GUID_ENTRY(FORMAT_VIDEOINFO2,                           0xf72a76a0, 0xeb0a, 0x11d0, 0xac, 0xe4, 0x00, 0x00, 0xc0, 0xcc, 0x16, 0xba)
OUR_GUID_ENTRY(IID_IKsDataTypeHandler,                      0x5ffbaa02, 0x49a3, 0x11d0, 0x9f, 0x36, 0x00, 0xaa, 0x00, 0xa2, 0x16, 0xa1)
OUR_GUID_ENTRY(IID_IKsInterfaceHandler,                     0xd3abc7e0, 0x9a61, 0x11d0, 0xa4, 0x0d, 0x00, 0xa0, 0xc9, 0x22, 0x31, 0x96)
OUR_GUID_ENTRY(IID_IKsPin,                                  0xb61178d1, 0xa2d9, 0x11cf, 0x9e, 0x53, 0x00, 0xaa, 0x00, 0xa2, 0x16, 0xa1)
OUR_GUID_ENTRY(IID_IKsPinFactory,                           0xcd5ebe6b, 0x8b6e, 0x11d1, 0x8a, 0xe0, 0x00, 0xa0, 0xc9, 0x22, 0x31, 0x96)
OUR_GUID_ENTRY(MEDIASUBTYPE_ATSC_SI,                        0xb3c7397c, 0xd303, 0x414d, 0xb3, 0x3c, 0x4e, 0xd2, 0xc9, 0xd2, 0x97, 0x33)
OUR_GUID_ENTRY(MEDIASUBTYPE_DOLBY_AC3,                      0xe06d802c, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIASUBTYPE_DTS,                            0xe06d8033, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIASUBTYPE_DVB_SI,                         0xe9dd31a3, 0x221d, 0x4adb, 0x85, 0x32, 0x9a, 0xf3, 0x09, 0xc1, 0xa4, 0x08)
OUR_GUID_ENTRY(MEDIASUBTYPE_DVD_LPCM_AUDIO,                 0xe06d8032, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIASUBTYPE_DVD_NAVIGATION_DSI,             0xe06d8030, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIASUBTYPE_DVD_NAVIGATION_PCI,             0xe06d802f, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIASUBTYPE_DVD_NAVIGATION_PROVIDER,        0xe06d8031, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIASUBTYPE_DVD_SUBPICTURE,                 0xe06d802d, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIASUBTYPE_ISDB_SI,                        0xe89ad298, 0x3601, 0x4b06, 0xaa, 0xec, 0x9d, 0xde, 0xed, 0xcc, 0x5b, 0xd0)
OUR_GUID_ENTRY(MEDIASUBTYPE_MPEG2DATA,                      0xc892e55b, 0x252d, 0x42b5, 0xa3, 0x16, 0xd9, 0x97, 0xe7, 0xa5, 0xd9, 0x95)
OUR_GUID_ENTRY(MEDIASUBTYPE_MPEG2_AUDIO,                    0xe06d802b, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIASUBTYPE_MPEG2_PBDA_TRANSPORT_PROCESSED, 0xaf748dd4, 0x0d80, 0x11db, 0x97, 0x05, 0x00, 0x50, 0x56, 0xc0, 0x00, 0x08)
OUR_GUID_ENTRY(MEDIASUBTYPE_MPEG2_PBDA_TRANSPORT_RAW,       0x0d7aed42, 0xcb9a, 0x11db, 0x97, 0x05, 0x00, 0x50, 0x56, 0xc0, 0x00, 0x08)
OUR_GUID_ENTRY(MEDIASUBTYPE_MPEG2_PROGRAM,                  0xe06d8022, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIASUBTYPE_MPEG2_TRANSPORT,                0xe06d8023, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIASUBTYPE_MPEG2_TRANSPORT_STRIDE,         0x138aa9a4, 0x1ee2, 0x4c5b, 0x98, 0x8e, 0x19, 0xab, 0xfd, 0xbc, 0x8a, 0x11)
OUR_GUID_ENTRY(MEDIASUBTYPE_MPEG2_UDCR_TRANSPORT,           0x18bec4ea, 0x4676, 0x450e, 0xb4, 0x78, 0x0c, 0xd8, 0x4c, 0x54, 0xb3, 0x27)
OUR_GUID_ENTRY(MEDIASUBTYPE_MPEG2_VERSIONED_TABLES,         0x1ed988b0, 0x3ffc, 0x4523, 0x87, 0x25, 0x34, 0x7b, 0xee, 0xc1, 0xa8, 0xa0)
OUR_GUID_ENTRY(MEDIASUBTYPE_MPEG2_VIDEO,                    0xe06d8026, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIASUBTYPE_MPEG2_WMDRM_TRANSPORT,          0x18bec4ea, 0x4676, 0x450e, 0xb4, 0x78, 0x0c, 0xd8, 0x4c, 0x54, 0xb3, 0x27)
OUR_GUID_ENTRY(MEDIASUBTYPE_SDDS,                           0xe06d8034, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIASUBTYPE_TIF_SI,                         0xec232eb2, 0xcb96, 0x4191, 0xb2, 0x26, 0x0e, 0xa1, 0x29, 0xf3, 0x82, 0x50)
OUR_GUID_ENTRY(MEDIATYPE_DVD_ENCRYPTED_PACK,                0xed0b916a, 0x044d, 0x11d1, 0xaa, 0x78, 0x00, 0xc0, 0x4f, 0xc3, 0x1d, 0x60)
OUR_GUID_ENTRY(MEDIATYPE_DVD_NAVIGATION,                    0xe06d802e, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIATYPE_MPEG2_PACK,                        0x36523b13, 0x8ee5, 0x11d1, 0x8c, 0xa3, 0x00, 0x60, 0xb0, 0x57, 0x66, 0x4a)
OUR_GUID_ENTRY(MEDIATYPE_MPEG2_PES,                         0xe06d8020, 0xdb46, 0x11cf, 0xb4, 0xd1, 0x00, 0x80, 0x5f, 0x6c, 0xbb, 0xea)
OUR_GUID_ENTRY(MEDIATYPE_MPEG2_SECTIONS,                    0x455f176c, 0x4b06, 0x47ce, 0x9a, 0xef, 0x8c, 0xae, 0xf7, 0x3d, 0xf7, 0xb5)
/* FIXME: conflicts with devicetopology.h */
/* OUR_GUID_ENTRY(IID_IKsControl,                              0x28f54685, 0x06fd, 0x11d2, 0xb2, 0x7a, 0x00, 0xa0, 0xc9, 0x22, 0x31, 0x96) */
