/*
 * Defines GUIDs for device classes
 *
 * Copyright (C) 2004 CodeWeavers (Aric Stewart)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

DEFINE_GUID( GUID_DEVCLASS_1394,
  0x6BDD1FC1, 0x810F, 0x11D0, 0xBE, 0xC7, 0x08, 0x00, 0x2B, 0xE2, 0x09, 0x2F );
DEFINE_GUID( GUID_DEVCLASS_1394DEBUG,
  0x66F250D6, 0x7801, 0x4A64, 0xB1, 0x39, 0xEE, 0xA8, 0x0A, 0x45, 0x0B, 0x24 );
DEFINE_GUID( GUID_DEVCLASS_61883,
  0x7EBEFBC0, 0x3200, 0x11D2, 0xB4, 0xC2, 0x00, 0xA0, 0xC9, 0x69, 0x7D, 0x07 );
DEFINE_GUID( GUID_DEVCLASS_ADAPTER,
  0x4D36E964, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_APMSUPPORT,
  0xD45B1C18, 0xC8FA, 0x11D1, 0x9F, 0x77, 0x00, 0x00, 0xF8, 0x05, 0xF5, 0x30 );
DEFINE_GUID( GUID_DEVCLASS_AVC,
  0xC06FF265, 0xAE09, 0x48F0, 0x81, 0x2C, 0x16, 0x75, 0x3D, 0x7C, 0xBA, 0x83 );
DEFINE_GUID( GUID_DEVCLASS_BATTERY,
  0x72631E54, 0x78A4, 0x11D0, 0xBC, 0xF7, 0x00, 0xAA, 0x00, 0xB7, 0xB3, 0x2A );
DEFINE_GUID( GUID_DEVCLASS_BIOMETRIC,
  0x53D29EF7, 0x377C, 0x4D14, 0x86, 0x4B, 0xEB, 0x3A, 0x85, 0x76, 0x93, 0x59 );
DEFINE_GUID( GUID_DEVCLASS_BLUETOOTH,
  0xE0CBF06C, 0xCD8B, 0x4647, 0xBB, 0x8A, 0x26, 0x3B, 0x43, 0xF0, 0xF9, 0x74 );
DEFINE_GUID( GUID_DEVCLASS_CAMERA,
  0xCA3E7AB9, 0xB4C3, 0x4AE6, 0x82, 0x51, 0x57, 0x9E, 0xF9, 0x33, 0x89, 0x0F );
DEFINE_GUID( GUID_DEVCLASS_CDROM,
  0x4D36E965, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_COMPUTER,
  0x4D36E966, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_DECODER,
  0x6BDD1FC2, 0x810F, 0x11D0, 0xBE, 0xC7, 0x08, 0x00, 0x2B, 0xE2, 0x09, 0x2F );
DEFINE_GUID( GUID_DEVCLASS_DISKDRIVE,
  0x4D36E967, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_DISPLAY,
  0x4D36E968, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_DOT4,
  0x48721B56, 0x6795, 0x11D2, 0xB1, 0xA8, 0x00, 0x80, 0xC7, 0x2E, 0x74, 0xA2 );
DEFINE_GUID( GUID_DEVCLASS_DOT4PRINT,
  0x49CE6AC8, 0x6F86, 0x11D2, 0xB1, 0xE5, 0x00, 0x80, 0xC7, 0x2E, 0x74, 0xA2 );
DEFINE_GUID( GUID_DEVCLASS_EHSTORAGESILO,
  0x9DA2B80F, 0xF89F, 0x4A49, 0xA5, 0xC2, 0x51, 0x1B, 0x08, 0x5B, 0x9E, 0x8A );
DEFINE_GUID( GUID_DEVCLASS_ENUM1394,
  0xC459DF55, 0xDB08, 0x11D1, 0xB0, 0x09, 0x00, 0xA0, 0xC9, 0x08, 0x1F, 0xF6 );
DEFINE_GUID( GUID_DEVCLASS_EXTENSION,
  0xE2F84CE7, 0x8EFA, 0x411C, 0xAA, 0x69, 0x97, 0x45, 0x4C, 0xA4, 0xcb, 0x57 );
DEFINE_GUID( GUID_DEVCLASS_FDC,
  0x4D36E969, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_FIRMWARE,
  0xF2E7DD72, 0x6468, 0x4E36, 0xB6, 0xF1, 0x64, 0x88, 0xF4, 0x2C, 0x1B, 0x52 );
DEFINE_GUID( GUID_DEVCLASS_FLOPPYDISK,
  0x4D36E980, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_GPS,
  0x6BDD1FC3, 0x810F, 0x11D0, 0xBE, 0xC7, 0x08, 0x00, 0x2B, 0xE2, 0x09, 0x2F );
DEFINE_GUID( GUID_DEVCLASS_HDC,
  0x4D36E96A, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_HIDCLASS,
  0x745A17A0, 0x74D3, 0x11D0, 0xB6, 0xFE, 0x00, 0xA0, 0xC9, 0x0F, 0x57, 0xDA );
DEFINE_GUID( GUID_DEVCLASS_HOLOGRAPHIC,
  0xD612553D, 0x06B1, 0x49CA, 0x89, 0x38, 0xE3, 0x9E, 0xF8, 0x0E, 0xB1, 0x6F );
DEFINE_GUID( GUID_DEVCLASS_IMAGE,
  0x6BDD1FC6, 0x810F, 0x11D0, 0xBE, 0xC7, 0x08, 0x00, 0x2B, 0xE2, 0x09, 0x2F );
DEFINE_GUID( GUID_DEVCLASS_INFINIBAND,
  0x30EF7132, 0xD858, 0x4A0C, 0xAC, 0x24, 0xB9, 0x02, 0x8A, 0x5C, 0xCA, 0x3F );
DEFINE_GUID( GUID_DEVCLASS_INFRARED,
  0x6BDD1FC5, 0x810F, 0x11D0, 0xBE, 0xC7, 0x08, 0x00, 0x2B, 0xE2, 0x09, 0x2F );
DEFINE_GUID( GUID_DEVCLASS_KEYBOARD,
  0x4D36E96B, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_LEGACYDRIVER,
  0x8ECC055D, 0x047F, 0x11D1, 0xA5, 0x37, 0x00, 0x00, 0xF8, 0x75, 0x3E, 0xD1 );
DEFINE_GUID( GUID_DEVCLASS_MEDIA,
  0x4D36E96C, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_MEDIUM_CHANGER,
  0xCE5939AE, 0xEBDE, 0x11D0, 0xB1, 0x81, 0x00, 0x00, 0xF8, 0x75, 0x3E, 0xC4 );
DEFINE_GUID( GUID_DEVCLASS_MEMORY,
  0x5099944A, 0xF6B9, 0x4057, 0xA0, 0x56, 0x8C, 0x55, 0x02, 0x28, 0x54, 0x4C );
DEFINE_GUID( GUID_DEVCLASS_MODEM,
  0x4D36E96D, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_MONITOR,
  0x4D36E96E, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_MOUSE,
  0x4D36E96F, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_MTD,
  0x4D36E970, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_MULTIFUNCTION,
  0x4D36E971, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_MULTIPORTSERIAL,
  0x50906CB8, 0xBA12, 0x11D1, 0xBF, 0x5D, 0x00, 0x00, 0xF8, 0x05, 0xF5, 0x30 );
DEFINE_GUID( GUID_DEVCLASS_NET,
  0x4D36E972, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_NETCLIENT,
  0x4D36E973, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_NETDRIVER,
  0x87EF9AD1, 0x8F70, 0x49EE, 0xB2, 0x15, 0xAB, 0x1F, 0xCA, 0xDC, 0xBE, 0x3C );
DEFINE_GUID( GUID_DEVCLASS_NETSERVICE,
  0x4D36E974, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_NETTRANS,
  0x4D36E975, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_NODRIVER,
  0x4D36E976, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_PCMCIA,
  0x4D36E977, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_PORTS,
  0x4D36E978, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_PNPPRINTERS,
  0x4658EE7E, 0xF050, 0x11D1, 0xB6, 0xBD, 0x00, 0xC0, 0x4F, 0xA3, 0x72, 0xA7 );
DEFINE_GUID( GUID_DEVCLASS_PRINTER,
  0x4D36E979, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_PRINTERUPGRADE,
  0x4D36E97A, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_PRINTQUEUE,
  0x1ED2BBF9, 0x11F0, 0x4084, 0xB2, 0x1F, 0xAD, 0x83, 0xA8, 0xE6, 0xDC, 0xDC );
DEFINE_GUID( GUID_DEVCLASS_PROCESSOR,
  0x50127DC3, 0x0F36, 0x415E, 0xA6, 0xCC, 0x4C, 0xB3, 0xBE, 0x91, 0x0B, 0x65 );
DEFINE_GUID( GUID_DEVCLASS_SBP2,
  0xD48179BE, 0xEC20, 0x11D1, 0xB6, 0xb8, 0x00, 0xC0, 0x4F, 0xA3, 0x72, 0xA7 );
DEFINE_GUID( GUID_DEVCLASS_SCMDISK,
  0x53966CB1, 0x4D46, 0x4166, 0xBF, 0x23, 0xC5, 0x22, 0x40, 0x3C, 0xD4, 0x95 );
DEFINE_GUID( GUID_DEVCLASS_SCMVOLUME,
  0x53CCB149, 0xE543, 0x4C84, 0xB6, 0xe0, 0xBC, 0xE4, 0xF6, 0xB7, 0xE8, 0x06 );
DEFINE_GUID( GUID_DEVCLASS_SCSIADAPTER,
  0x4D36E97B, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_SECURITYACCELERATOR,
  0x268C95A1, 0xEDFE, 0x11D3, 0x95, 0xC3, 0x00, 0x10, 0xDC, 0x40, 0x50, 0xA5 );
DEFINE_GUID( GUID_DEVCLASS_SENSOR,
  0x5175D334, 0xC371, 0x4806, 0xB3, 0xBA, 0x71, 0xFD, 0x53, 0xC9, 0x25, 0x8D );
DEFINE_GUID( GUID_DEVCLASS_SIDESHOW,
  0x997B5D8D, 0xC442, 0x4F2E, 0xBA, 0xF3, 0x9C, 0x8E, 0x67, 0x1E, 0x9E, 0x21 );
DEFINE_GUID( GUID_DEVCLASS_SMARTCARDREADER,
  0x50DD5230, 0xBA8A, 0x11D1, 0xBF, 0x5D, 0x00, 0x00, 0xF8, 0x05, 0xF5, 0x30 );
DEFINE_GUID( GUID_DEVCLASS_SMRDISK,
  0x53487C23, 0x680F, 0x4585, 0xAC, 0xC3, 0x1F, 0x10, 0xD6, 0x77, 0x7E, 0x82 );
DEFINE_GUID( GUID_DEVCLASS_SMRVOLUME,
  0x53B3CF03, 0x8F5A, 0x4788, 0x91, 0xB6, 0xD1, 0x9E, 0xD9, 0xFC, 0xCC, 0xBF );
DEFINE_GUID( GUID_DEVCLASS_SOFTWARECOMPONENT,
  0x5C4C3332, 0x344D, 0x483C, 0x87, 0x39, 0x25, 0x9E, 0x93, 0x4C, 0x9C, 0xC8 );
DEFINE_GUID( GUID_DEVCLASS_SOUND,
  0x4D36E97C, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_SYSTEM,
  0x4D36E97D, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_TAPEDRIVE,
  0x6D807884, 0x7D21, 0x11CF, 0x80, 0x1C, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_UNKNOWN,
  0x4D36E97E, 0xE325, 0x11CE, 0xBF, 0xC1, 0x08, 0x00, 0x2B, 0xE1, 0x03, 0x18 );
DEFINE_GUID( GUID_DEVCLASS_UCM,
  0xE6F1AA1C, 0x7F3B, 0x4473, 0xB2, 0xE8, 0xC9, 0x7D, 0x8A, 0xC7, 0x1D, 0x53 );
DEFINE_GUID( GUID_DEVCLASS_USB,
  0x36FC9E60, 0xC465, 0x11CF, 0x80, 0x56, 0x44, 0x45, 0x53, 0x54, 0x00, 0x00 );
DEFINE_GUID( GUID_DEVCLASS_VOLUME,
  0x71A27CDD, 0x812A, 0x11D0, 0xBE, 0xC7, 0x08, 0x00, 0x2B, 0xE2, 0x09, 0x2F );
DEFINE_GUID( GUID_DEVCLASS_VOLUMESNAPSHOT,
  0x533C5B84, 0xEC70, 0x11D2, 0x95, 0x05, 0x00, 0xC0, 0x4F, 0x79, 0xDE, 0xAF );
DEFINE_GUID( GUID_DEVCLASS_WCEUSBS,
  0x25DBCE51, 0x6C8f, 0x4A72, 0x8A, 0x6D, 0xB5, 0x4C, 0x2B, 0x4F, 0xC8, 0x35 );
DEFINE_GUID( GUID_DEVCLASS_WPD,
  0xEEC5AD98, 0x8080, 0x425F, 0x92, 0x2A, 0xDA, 0xBF, 0x3D, 0xE3, 0xF6, 0x9A );

DEFINE_GUID( GUID_DEVCLASS_FSFILTER_TOP,
  0xB369BAF4, 0x5568, 0x4E82, 0xA8, 0x7E, 0xA9, 0x3E, 0xB1, 0x6B, 0xCA, 0x87 );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_ACTIVITYMONITOR,
  0xB86DFF51, 0xA31E, 0x4BAC, 0xB3, 0xCF, 0xE8, 0xCF, 0xE7, 0x5C, 0x9F, 0xC2 );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_UNDELETE,
  0xFE8F1572, 0xC67A, 0x48C0, 0xBB, 0xAC, 0x0B, 0x5C, 0x6D, 0x66, 0xCA, 0xFB );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_ANTIVIRUS,
  0xB1D1A169, 0xC54F, 0x4379, 0x81, 0xDB, 0xBE, 0xE7, 0xD8, 0x8D, 0x74, 0x54 );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_REPLICATION,
  0x48D3EBC4, 0x4CF8, 0x48FF, 0xB8, 0x69, 0x9C, 0x68, 0xAD, 0x42, 0xEB, 0x9F );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_CONTINUOUSBACKUP,
  0x71AA14F8, 0x6FAD, 0x4622, 0xAD, 0x77, 0x92, 0xBB, 0x9D, 0x7E, 0x69, 0x47 );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_CONTENTSCREENER,
  0x3E3F0674, 0xC83C, 0x4558, 0xBB, 0x26, 0x98, 0x20, 0xE1, 0xEB, 0xA5, 0xC5 );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_QUOTAMANAGEMENT,
  0x8503C911, 0xA6C7, 0x4919, 0x8F, 0x79, 0x50, 0x28, 0xF5, 0x86, 0x6B, 0x0C );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_SYSTEMRECOVERY,
  0x2DB15374, 0x706E, 0x4131, 0xA0, 0xC7, 0xD7, 0xC7, 0x8E, 0xB0, 0x28, 0x9A );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_CFSMETADATASERVER,
  0xCDCF0939, 0xB75B, 0x4630, 0xBF, 0x76, 0x80, 0xF7, 0xBA, 0x65, 0x58, 0x84 );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_HSM,
  0xD546500A, 0x2AEB, 0x45F6, 0x94, 0x82, 0xF4, 0xB1, 0x79, 0x9C, 0x31, 0x77 );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_COMPRESSION,
  0xF3586BAF, 0xB5AA, 0x49B5, 0x8D, 0x6C, 0x05, 0x69, 0x28, 0x4C, 0x63, 0x9F );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_ENCRYPTION,
  0xA0A701C0, 0xA511, 0x42FF, 0xAA, 0x6C, 0x06, 0xDC, 0x03, 0x95, 0x57, 0x6F );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_VIRTUALIZATION,
  0xF75A86C0, 0x10D8, 0x4C3A, 0xB2, 0x33, 0xED, 0x60, 0xE4, 0xCD, 0xFA, 0xAC );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_PHYSICALQUOTAMANAGEMENT,
  0x6A0A8E78, 0xBBA6, 0x4FC4, 0xA7, 0x09, 0x1E, 0x33, 0xCD, 0x09, 0xD6, 0x7E );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_OPENFILEBACKUP,
  0xF8ECAFA6, 0x66D1, 0x41A5, 0x89, 0x9B, 0x66, 0x58, 0x5D, 0x72, 0x16, 0xB7 );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_SECURITYENHANCER,
  0xD02BC3DA, 0x0C8E, 0x4945, 0x9B, 0xD5, 0xF1, 0x88, 0x3C, 0x22, 0x6C, 0x8C );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_COPYPROTECTION,
  0x89786FF1, 0x9C12, 0x402F, 0x9C, 0x9E, 0x17, 0x75, 0x3C, 0x7F, 0x43, 0x75 );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_BOTTOM,
  0x37765EA0, 0x5958, 0x4FC9, 0xB0, 0x4B, 0x2f, 0xDF, 0xEF, 0x97, 0xE5, 0x9E );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_SYSTEM,
  0x5D1B9AAA, 0x01E2, 0x46AF, 0x84, 0x9F, 0x27, 0x2B, 0x3F, 0x32, 0x4C, 0x46 );
DEFINE_GUID( GUID_DEVCLASS_FSFILTER_INFRASTRUCTURE,
  0xE55FA6F9, 0x128C, 0x4D04, 0xAB, 0xAB, 0x63, 0x0C, 0x74, 0xB1, 0x45, 0x3A );
